@@ -6,6 +6,7 @@ from .licenses_app import LicensesApp
 from .handlers import add_handlers, LabHandler, LabConfig
 from .translation_utils import translator
 from .workspaces_app import WorkspaceExportApp, WorkspaceImportApp, WorkspaceListApp
+from .workspaces_handler import slugify, WORKSPACE_EXTENSION
 from ._version import __version__
 
 __all__ = [
@@ -16,7 +17,9 @@ __all__ = [
     'LabServerApp',
     'LicensesApp',
     'SETTINGS_EXTENSION',
+    'slugify',
     'translator',
+    'WORKSPACE_EXTENSION',
     'WorkspaceExportApp',
     'WorkspaceImportApp',
     'WorkspaceListApp'
